@@ -1,13 +1,12 @@
-<?php
+<?php declare(strict_types=1);
 /*
- * This file is part of php-token-stream.
+ * This file is part of phpunit/php-token-stream.
  *
  * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-
 use PHPUnit\Framework\TestCase;
 
 class PHP_Token_InterfaceTest extends TestCase
@@ -22,7 +21,7 @@ class PHP_Token_InterfaceTest extends TestCase
      */
     private $interfaces;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $ts = new PHP_Token_Stream(TEST_FILES_PATH . 'source4.php');
         $i  = 0;
@@ -37,60 +36,44 @@ class PHP_Token_InterfaceTest extends TestCase
         }
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::getName
-     */
-    public function testGetName()
+    public function testGetName(): void
     {
         $this->assertEquals(
-            'iTemplate', $this->interfaces[0]->getName()
+            'iTemplate',
+            $this->interfaces[0]->getName()
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::getParent
-     */
-    public function testGetParentNotExists()
+    public function testGetParentNotExists(): void
     {
         $this->assertFalse(
             $this->interfaces[0]->getParent()
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::hasParent
-     */
-    public function testHasParentNotExists()
+    public function testHasParentNotExists(): void
     {
         $this->assertFalse(
             $this->interfaces[0]->hasParent()
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::getParent
-     */
-    public function testGetParentExists()
+    public function testGetParentExists(): void
     {
         $this->assertEquals(
-            'a', $this->interfaces[2]->getParent()
+            'a',
+            $this->interfaces[2]->getParent()
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::hasParent
-     */
-    public function testHasParentExists()
+    public function testHasParentExists(): void
     {
         $this->assertTrue(
             $this->interfaces[2]->hasParent()
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::getInterfaces
-     */
-    public function testGetInterfacesExists()
+    public function testGetInterfacesExists(): void
     {
         $this->assertEquals(
             ['b'],
@@ -98,23 +81,16 @@ class PHP_Token_InterfaceTest extends TestCase
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::hasInterfaces
-     */
-    public function testHasInterfacesExists()
+    public function testHasInterfacesExists(): void
     {
         $this->assertTrue(
             $this->class->hasInterfaces()
         );
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::getPackage
-     */
-    public function testGetPackageNamespace()
+    public function testGetPackageNamespace(): void
     {
-        $tokenStream = new PHP_Token_Stream(TEST_FILES_PATH . 'classInNamespace.php');
-        foreach ($tokenStream as $token) {
+        foreach (new PHP_Token_Stream(TEST_FILES_PATH . 'classInNamespace.php') as $token) {
             if ($token instanceof PHP_Token_INTERFACE) {
                 $package = $token->getPackage();
                 $this->assertSame('Foo\\Bar', $package['namespace']);
@@ -122,7 +98,6 @@ class PHP_Token_InterfaceTest extends TestCase
         }
     }
 
-
     public function provideFilesWithClassesWithinMultipleNamespaces()
     {
         return [
@@ -133,18 +108,19 @@ class PHP_Token_InterfaceTest extends TestCase
 
     /**
      * @dataProvider provideFilesWithClassesWithinMultipleNamespaces
-     * @covers PHP_Token_INTERFACE::getPackage
      */
-    public function testGetPackageNamespaceForFileWithMultipleNamespaces($filepath)
+    public function testGetPackageNamespaceForFileWithMultipleNamespaces($filepath): void
     {
         $tokenStream     = new PHP_Token_Stream($filepath);
         $firstClassFound = false;
+
         foreach ($tokenStream as $token) {
             if ($firstClassFound === false && $token instanceof PHP_Token_INTERFACE) {
                 $package = $token->getPackage();
                 $this->assertSame('TestClassInBar', $token->getName());
                 $this->assertSame('Foo\\Bar', $package['namespace']);
                 $firstClassFound = true;
+
                 continue;
             }
             // Secound class
@@ -159,7 +135,7 @@ class PHP_Token_InterfaceTest extends TestCase
         $this->fail('Searching for 2 classes failed');
     }
 
-    public function testGetPackageNamespaceIsEmptyForInterfacesThatAreNotWithinNamespaces()
+    public function testGetPackageNamespaceIsEmptyForInterfacesThatAreNotWithinNamespaces(): void
     {
         foreach ($this->interfaces as $token) {
             $package = $token->getPackage();
@@ -167,21 +143,21 @@ class PHP_Token_InterfaceTest extends TestCase
         }
     }
 
-    /**
-     * @covers PHP_Token_INTERFACE::getPackage
-     */
-    public function testGetPackageNamespaceWhenExtentingFromNamespaceClass()
+    public function testGetPackageNamespaceWhenExtentingFromNamespaceClass(): void
     {
         $tokenStream     = new PHP_Token_Stream(TEST_FILES_PATH . 'classExtendsNamespacedClass.php');
         $firstClassFound = false;
+
         foreach ($tokenStream as $token) {
             if ($firstClassFound === false && $token instanceof PHP_Token_INTERFACE) {
                 $package = $token->getPackage();
                 $this->assertSame('Baz', $token->getName());
                 $this->assertSame('Foo\\Bar', $package['namespace']);
                 $firstClassFound = true;
+
                 continue;
             }
+
             if ($token instanceof PHP_Token_INTERFACE) {
                 $package = $token->getPackage();
                 $this->assertSame('Extender', $token->getName());
@@ -190,6 +166,7 @@ class PHP_Token_InterfaceTest extends TestCase
                 return;
             }
         }
+
         $this->fail('Searching for 2 classes failed');
     }
 }
