@@ -1,24 +1,20 @@
-<?php
+<?php declare(strict_types=1);
 /*
- * This file is part of php-token-stream.
+ * This file is part of phpunit/php-token-stream.
  *
  * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-
 use PHPUnit\Framework\TestCase;
 
 class PHP_Token_NamespaceTest extends TestCase
 {
-    /**
-     * @covers PHP_Token_NAMESPACE::getName
-     */
-    public function testGetName()
+    public function testGetName(): void
     {
         $tokenStream = new PHP_Token_Stream(
-          TEST_FILES_PATH . 'classInNamespace.php'
+            TEST_FILES_PATH . 'classInNamespace.php'
         );
 
         foreach ($tokenStream as $token) {
@@ -28,39 +24,36 @@ class PHP_Token_NamespaceTest extends TestCase
         }
     }
 
-    public function testGetStartLineWithUnscopedNamespace()
+    public function testGetStartLineWithUnscopedNamespace(): void
     {
-        $tokenStream = new PHP_Token_Stream(TEST_FILES_PATH . 'classInNamespace.php');
-        foreach ($tokenStream as $token) {
+        foreach (new PHP_Token_Stream(TEST_FILES_PATH . 'classInNamespace.php') as $token) {
             if ($token instanceof PHP_Token_NAMESPACE) {
                 $this->assertSame(2, $token->getLine());
             }
         }
     }
 
-    public function testGetEndLineWithUnscopedNamespace()
+    public function testGetEndLineWithUnscopedNamespace(): void
     {
-        $tokenStream = new PHP_Token_Stream(TEST_FILES_PATH . 'classInNamespace.php');
-        foreach ($tokenStream as $token) {
+        foreach (new PHP_Token_Stream(TEST_FILES_PATH . 'classInNamespace.php') as $token) {
             if ($token instanceof PHP_Token_NAMESPACE) {
                 $this->assertSame(2, $token->getEndLine());
             }
         }
     }
-    public function testGetStartLineWithScopedNamespace()
+
+    public function testGetStartLineWithScopedNamespace(): void
     {
-        $tokenStream = new PHP_Token_Stream(TEST_FILES_PATH . 'classInScopedNamespace.php');
-        foreach ($tokenStream as $token) {
+        foreach (new PHP_Token_Stream(TEST_FILES_PATH . 'classInScopedNamespace.php') as $token) {
             if ($token instanceof PHP_Token_NAMESPACE) {
                 $this->assertSame(2, $token->getLine());
             }
         }
     }
 
-    public function testGetEndLineWithScopedNamespace()
+    public function testGetEndLineWithScopedNamespace(): void
     {
-        $tokenStream = new PHP_Token_Stream(TEST_FILES_PATH . 'classInScopedNamespace.php');
-        foreach ($tokenStream as $token) {
+        foreach (new PHP_Token_Stream(TEST_FILES_PATH . 'classInScopedNamespace.php') as $token) {
             if ($token instanceof PHP_Token_NAMESPACE) {
                 $this->assertSame(8, $token->getEndLine());
             }
